//
//  TableViewController.m
//  ScrollingRows
//
//  Created by Dan Messing on 3/6/13.
//  Copyright (c) 2013 Dan Messing. All rights reserved.
//

#import "TableViewController.h"
#import "TableCell.h"
#import "CollectionViewCell.h"


@interface TableViewController ()

@property NSArray *modelData;
@property NSMutableArray *scrollPositions;

@end


@implementation TableViewController


- (void)viewDidLoad
{
    [super viewDidLoad];
	
	self.tableView.backgroundColor = [UIColor blackColor];
	self.tableView.separatorColor = [UIColor blackColor];
	
	
	self.modelData = @[
  
		@[@"1", @"2", @"3", @"4", @"5", @"6", @"7", @"8"],
		@[@"one", @"two", @"three", @"four", @"five", @"six"],
		@[@"alpha", @"beta", @"gamma", @"delta", @"epsilon", @"zeta", @"eta", @"theta", @"iota", @"kappa", @"lambda", @"mu"],
		@[@"a", @"b", @"c", @"x", @"y", @"z"],
		@[@"Aries", @"Taurus", @"Gemini", @"Cancer", @"Leo", @"Virgo", @"Libra", @"Scorpio", @"Sagittarius", @"Capricorn", @"Aquarius", @"Pisces"],
		@[@"Mercury", @"Venus", @"Earth", @"Mars", @"Jupiter", @"Saturn", @"Uranus", @"Neptune"],
		@[@"I", @"II", @"III", @"IV", @"V", @"VI", @"VII", @"VIII", @"IX", @"X"],
		@[@"1", @"2", @"3", @"4", @"5", @"6", @"7", @"8"],
		@[@"one", @"two", @"three", @"four", @"five", @"six"],
		@[@"alpha", @"beta", @"gamma", @"delta", @"epsilon", @"zeta", @"eta", @"theta", @"iota", @"kappa", @"lambda", @"mu"],
		@[@"a", @"b", @"c", @"x", @"y", @"z"],
		@[@"Aries", @"Taurus", @"Gemini", @"Cancer", @"Leo", @"Virgo", @"Libra", @"Scorpio", @"Sagittarius", @"Capricorn", @"Aquarius", @"Pisces"],
		@[@"Mercury", @"Venus", @"Earth", @"Mars", @"Jupiter", @"Saturn", @"Uranus", @"Neptune"]
  
		];
	
	self.scrollPositions = [NSMutableArray new];
	for ( int i = 0; i < self.modelData.count; i++ )
	{
		[self.scrollPositions addObject:@0];
	}
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return self.modelData.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    TableCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    
	cell.collectionView.contentOffset = CGPointMake([self.scrollPositions[indexPath.row] floatValue], 0);
	cell.collectionView.dataSource = self;
	[cell.collectionView reloadData];
    
    return cell;
}


#pragma mark - Table view delegate


- (void)tableView:(UITableView *)tableView didEndDisplayingCell:(UITableViewCell *)cell forRowAtIndexPath:(NSIndexPath *)indexPath
{
	UICollectionView *collectionView = ((TableCell *)cell).collectionView;
	
	// so reused cells don't show up scrolling
	[collectionView setContentOffset:collectionView.contentOffset animated:NO];

	[self.scrollPositions replaceObjectAtIndex:indexPath.row withObject:@(collectionView.contentOffset.x)];
}


#pragma mark - CollectionView Data Source


- (NSInteger)numberOfSectionsInCollectionView:(UICollectionView *)collectionView
{
	return 1;
}


- (NSInteger)collectionView:(UICollectionView *)collectionView numberOfItemsInSection:(NSInteger)section
{
	UITableViewCell *tableCell = (UITableViewCell *)[[collectionView superview] superview];
	NSUInteger tableRow = [self.tableView indexPathForCell:tableCell].row;
	
	return [self.modelData[tableRow] count];
}


- (UICollectionViewCell *)collectionView:(UICollectionView *)collectionView cellForItemAtIndexPath:(NSIndexPath *)indexPath
{
	static NSString *CollectionCellIdentifier = @"CollectionCell";
	CollectionViewCell *cell = [collectionView dequeueReusableCellWithReuseIdentifier:CollectionCellIdentifier forIndexPath:indexPath];
	
	UITableViewCell *tableCell = (UITableViewCell *)[[collectionView superview] superview];
	NSUInteger tableRow = [self.tableView indexPathForCell:tableCell].row;
	
	cell.label.text = self.modelData[tableRow][indexPath.row];
	
	return cell;
}


@end
